@@ -50,6 +50,15 @@ class TestDAWG(object):
                 d.read(f)
                 assert 'Invalid' in e.args[0]
 
+    def test_no_segfaults_after_wrong_stream(self):
+        d = dawg.DAWG()
+        wrong_path = tempfile.mktemp()  # file doesn't exists
+
+        with pytest.raises(IOError):
+            d.load(wrong_path)
+
+        assert 'random-key' not in d # there is possible segfault
+
     def test_build_errors(self):
         with pytest.raises(dawg.Error):
             data = [b'foo\x00bar', b'bar']
